@@ -9,6 +9,7 @@ common_string = pc.common_substring(sys.argv[1:])
 merged = 'merged_{}.csv'.format(common_string)
 baseline_name = 'msfem.all'
 
+
 def _get(func_name='scaleup'):
     header, current = pc.read_files(sys.argv[1:])
     headerlist = header['profiler']
@@ -18,6 +19,7 @@ def _get(func_name='scaleup'):
     current.transpose().to_csv('{}_{}'.format(merged, func_name))
     return current
 
+
 current = _get('scaleup')
 pc.plot_msfem(current, merged, series_name='scaleup', xcol='grids.total_macro_cells')
 
@@ -25,10 +27,16 @@ current = _get('speedup')
 pc.plot_msfem(current, merged, series_name='speedup', xcol='cores')
 
 try:
-    pc.plot_error(data_frame=current, filename_base='{}_errors'.format(merged),
-                  error_cols=['msfem_exact_H1s', 'msfem_exact_L2', 'fem_exact_H1s', 'fem_exact_L2'],
-                  xcol='grids.micro_cells_per_macrocell_dim', labels=['MsFEM $H^1_s$', 'MsFEM $L^2$', 'CgFEM $H^1_s$', 'CgFEM $L^2$'],
-                  baseline_name=baseline_name, logy_base=10,logx_base=2)
+    pc.plot_error(
+        data_frame=current,
+        filename_base='{}_errors'.format(merged),
+        error_cols=['msfem_exact_H1s', 'msfem_exact_L2', 'fem_exact_H1s', 'fem_exact_L2'],
+        xcol='grids.micro_cells_per_macrocell_dim',
+        labels=['MsFEM $H^1_s$', 'MsFEM $L^2$', 'CgFEM $H^1_s$', 'CgFEM $L^2$'],
+        baseline_name=baseline_name,
+        logy_base=10,
+        logx_base=2,
+    )
 except KeyError as k:
     logging.error('No error data')
     logging.error(traceback.format_exc())
